==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketler",
    "Tag name is empty" : "Etiket adı boş",
    "Update" : "Güncelle",
    "Create" : "Ekle",
    "Select tag…" : "Etiket seçin...",
    "System tag %1$s added by the system" : "%1$s sistem etiketi sistem tarafından eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "System tag %1$s removed by the system" : "%1$s sistem etiketi sistem tarafından kaldırıldı",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "System tag %2$s was added to %1$s by the system" : "%2$s sistem etiketi %1$s dosyasına sistem tarafından eklendi",
    "System tag {systemtag} was added to {file} by the system" : "{systemtag} sistem etiketi {file} dosyasına sistem tarafından eklendi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "System tag %2$s was removed from %1$s by the system" : "%2$s sistem etiketi %1$s dosyasından sistem tarafından kaldırıldı",
    "System tag {systemtag} was removed from {file} by the system" : "{systemtag} sistem etiketi {file} dosyasından sistem tarafından kaldırıldı",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlı)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildi",
    "Collaborative tags" : "İşbirliği etiketleri",
    "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan işbirlikli etiketleme özelliği.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İşbirlikli etiketleme özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
    "Tagged files" : "Etiketli dosyalar",
    "Select tags to filter by" : "Süzülecek etiketleri seçin",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İşbirliği etiketlerini tüm kullanıcılar kullanabilir. Kısıtlı etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
    "Select tag …" : "Etiket seçin...",
    "Create a new tag" : "Etiket ekle",
    "Name" : "Ad",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlı",
    "Invisible" : "Gizli",
    "Delete" : "Sil",
    "Reset" : "Sıfırla",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Etiket adı boş",
    "Update" : "Güncelle",
    "Create" : "Ekle",
    "Select tag…" : "Etiket seçin …",
    "System tag %1$s added by the system" : "%1$s sistem etiketi sistem tarafından eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "System tag %1$s removed by the system" : "%1$s sistem etiketi sistem tarafından kaldırıldı",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "System tag %2$s was added to %1$s by the system" : "%2$s sistem etiketi %1$s dosyasına sistem tarafından eklendi",
    "System tag {systemtag} was added to {file} by the system" : "{systemtag} sistem etiketi {file} dosyasına sistem tarafından eklendi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "System tag %2$s was removed from %1$s by the system" : "%2$s sistem etiketi %1$s dosyasından sistem tarafından kaldırıldı",
    "System tag {systemtag} was removed from {file} by the system" : "{systemtag} sistem etiketi {file} dosyasından sistem tarafından kaldırıldı",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlı)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildi",
    "Tags" : "Etiketler",
    "Collaborative tags" : "İşbirliği etiketleri",
    "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan işbirlikli etiketleme özelliği.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İşbirlikli etiketleme özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
    "Tagged files" : "Etiketli dosyalar",
    "Select tags to filter by" : "Süzülecek etiketleri seçin",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İşbirliği etiketlerini tüm kullanıcılar kullanabilir. Kısıtlı etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
    "Select tag …" : "Etiket seçin …",
    "Create a new tag" : "Etiket ekle",
    "Name" : "Ad",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlı",
    "Invisible" : "Gizli",
    "Delete" : "Sil",
    "Reset" : "Sıfırla",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme"
},
"nplurals=2; plural=(n > 1);");
